==> tuia-advert-center-api-1.5.9-20180813.072955-39-sources.jar: cn/com/duiba/tuia/core/api/dto/AdvertDetailDto.java <==
/**
 * 文件名： AdvertDetail.java 此类描述的是： 作者: leiliang 创建时间: 2016年4月12日 下午4:46:12
 */
package cn.com.duiba.tuia.core.api.dto;

import java.io.Serializable;
import java.util.List;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * 广告详情.
 *
 * @author: leiliang
 * @version:
 */
public class AdvertDetailDto implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** 广告主id */
    private Long              advertiserId;
    
    /** 广告主名称. */
    private String            advertiserName;

    /** 广告计划. */
    private AdvertPlanDto     advertPlan;

    /** 广告优惠卷信息. */

    private AdvertCouponDto   advertCoupon;

    /** 广告标签. */
    private List<String>      tagNums;

    /** 广告屏蔽标签. */
    private List<String>      bannedTagNums;

    private Integer abate;

    public Integer getAbate() {
        return abate;
    }

    public void setAbate(Integer abate) {
        this.abate = abate;
    }

    /**
     * advertiserId.
     *
     * @return the advertiserId
     * @since JDK 1.8
     */
    public Long getAdvertiserId() {
        return advertiserId;
    }

    /**
     * advertiserId.
     *
     * @param advertiserId the advertiserId to set
     * @since JDK 1.8
     */
    public void setAdvertiserId(Long advertiserId) {
        this.advertiserId = advertiserId;
    }

    public List<String> getTagNums() {
        return tagNums;
    }

    public void setTagNums(List<String> tagNums) {
        this.tagNums = tagNums;
    }

    public List<String> getBannedTagNums() {
        return bannedTagNums;
    }

    public void setBannedTagNums(List<String> bannedTagNums) {
        this.bannedTagNums = bannedTagNums;
    }

    public String getAdvertiserName() {
        return advertiserName;
    }

    public void setAdvertiserName(String advertiserName) {
        this.advertiserName = advertiserName;
    }

    public AdvertPlanDto getAdvertPlan() {
        return advertPlan;
    }

    public void setAdvertPlan(AdvertPlanDto advertPlan) {
        this.advertPlan = advertPlan;
    }

    public AdvertCouponDto getAdvertCoupon() {
        return advertCoupon;
    }

    public void setAdvertCoupon(AdvertCouponDto advertCoupon) {
        this.advertCoupon = advertCoupon;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> tuia-advert-center-api-1.9.7-sources.jar: cn/com/duiba/tuia/core/api/dto/AdvertDetailDto.java <==
/**
 * 文件名： AdvertDetail.java 此类描述的是： 作者: leiliang 创建时间: 2016年4月12日 下午4:46:12
 */
package cn.com.duiba.tuia.core.api.dto;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.List;

/**
 * 广告详情.
 *
 * @author: leiliang
 * @version:
 */
public class AdvertDetailDto implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** 广告主id */
    private Long              advertiserId;
    
    /** 广告主名称. */
    private String            advertiserName;

    /** 广告计划. */
    private AdvertPlanDto     advertPlan;

    /** 广告优惠卷信息. */

    private AdvertCouponDto   advertCoupon;

    /**
     * 落地页关联方式
     */
    private Integer                  promoteType;

    //创意素材-大图
    private List<ImageDto> largeImageList;

    //创意素材-小图
    private List<ImageDto> smallImageList;

    /** 广告标签. */
    private List<String>      tagNums;

    /** 广告屏蔽标签. */
    private List<String>      bannedTagNums;

    private Integer abate;

    public Integer getPromoteType() {
        return promoteType;
    }

    public void setPromoteType(Integer promoteType) {
        this.promoteType = promoteType;
    }

    public Integer getAbate() {
        return abate;
    }

    public void setAbate(Integer abate) {
        this.abate = abate;
    }

    /**
     * advertiserId.
     *
     * @return the advertiserId
     * @since JDK 1.8
     */
    public Long getAdvertiserId() {
        return advertiserId;
    }

    /**
     * advertiserId.
     *
     * @param advertiserId the advertiserId to set
     * @since JDK 1.8
     */
    public void setAdvertiserId(Long advertiserId) {
        this.advertiserId = advertiserId;
    }

    public List<ImageDto> getLargeImageList() {
        return largeImageList;
    }

    public void setLargeImageList(List<ImageDto> largeImageList) {
        this.largeImageList = largeImageList;
    }

    public List<ImageDto> getSmallImageList() {
        return smallImageList;
    }

    public void setSmallImageList(List<ImageDto> smallImageList) {
        this.smallImageList = smallImageList;
    }

    public List<String> getTagNums() {
        return tagNums;
    }

    public void setTagNums(List<String> tagNums) {
        this.tagNums = tagNums;
    }

    public List<String> getBannedTagNums() {
        return bannedTagNums;
    }

    public void setBannedTagNums(List<String> bannedTagNums) {
        this.bannedTagNums = bannedTagNums;
    }

    public String getAdvertiserName() {
        return advertiserName;
    }

    public void setAdvertiserName(String advertiserName) {
        this.advertiserName = advertiserName;
    }

    public AdvertPlanDto getAdvertPlan() {
        return advertPlan;
    }

    public void setAdvertPlan(AdvertPlanDto advertPlan) {
        this.advertPlan = advertPlan;
    }

    public AdvertCouponDto getAdvertCoupon() {
        return advertCoupon;
    }

    public void setAdvertCoupon(AdvertCouponDto advertCoupon) {
        this.advertCoupon = advertCoupon;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
